@@ -1,8 +1,8 @@
 
-__version__ = "0.11"
+__version__ = "0.11.1"
 __version_vcs_info__ = {
     'branch': 'master',
-    'revid': '9f75385',
-    'revno': 1913}
+    'revid': '9b2dba5',
+    'revno': 1916}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
